Learn R Programming

MetChem (version 0.5)

chemical.dissimilarity: Chemical dissimilarity.

Description

This function calculates the structural dissimilarity between different metabolites using the simplified molecular-input line-entry system (SMILE) of each metabolite as input.

Usage

chemical.dissimilarity (smiles,method="tanimoto",type="extended")

Value

A list contains distance between fingerprints .

Arguments

smiles

A vector of smile notations.

method

The method used to calculated the distance between molecular fingerprint ("tanimoto" as default). For more information see fp.sim.matrix function.

type

The type of fingerprint applied to the SMILEs ("extended" as default). For more information see get.fingerprint function.

See Also

fp.sim.matrix, get.fingerprint,

Examples

Run this code

data(Metabolites)
d=chemical.dissimilarity(Metabolites$SMILES[1:50])

Run the code above in your browser using DataLab