powered by
This function calculates the structural dissimilarity between different metabolites using the simplified molecular-input line-entry system (SMILE) of each metabolite as input.
chemical.dissimilarity (smiles,method="tanimoto",type="extended")
A list contains distance between fingerprints .
A vector of smile notations.
The method used to calculated the distance between molecular fingerprint ("tanimoto" as default). For more information see fp.sim.matrix function.
fp.sim.matrix
The type of fingerprint applied to the SMILEs ("extended" as default). For more information see get.fingerprint function.
get.fingerprint
fp.sim.matrix, get.fingerprint,
data(Metabolites) d=chemical.dissimilarity(Metabolites$SMILES[1:50])
Run the code above in your browser using DataLab